@@ -4,8 +4,10 @@ import pickle
 import pandas as pd
 
 
-def file_prefix_time():
-    return time.strftime('%Y%m%d', time.localtime())
+def file_prefix_time(with_dash=False):
+    curr_time = time.strftime('%Y%m%d', time.localtime())
+    prefix = curr_time + '-' if with_dash else curr_time
+    return prefix
 
 
 def pd_read_csv_skip_row(file, comment=None, **kwargs):
@@ -21,10 +23,10 @@ def pd_read_csv_skip_row(file, comment=None, **kwargs):
     return pd.read_csv(f, **kwargs)
 
 
-def read_one_col_file(file, header=None):
+def read_one_col_file(file, skiprows=None):
     with open(file, 'r') as f:
         one_col_list = [_.strip('\n') for _ in f.readlines()]
-        one_col_list = one_col_list[1:] if header else one_col_list
+        one_col_list = one_col_list[skiprows:] if skiprows else one_col_list
         while '' in one_col_list:
             one_col_list.remove('')
     return one_col_list
@@ -41,13 +43,20 @@ def process_list_or_file(x):
     return target_list
 
 
-def data_dump_load_skip(file_path, data=None):
+def data_dump_load_skip(file_path, data=None, update=False):
     if not os.path.exists(file_path):
-        with open(file_path, 'wb') as f:
-            pickle.dump(data, f)
+        if data is not None:  # Here use 'is not None' because some thing will be wrong when the data is a pd.DataFrame. (Truth value is ambiguous error)
+            with open(file_path, 'wb') as f:
+                pickle.dump(data, f)
+        else:
+            raise FileNotFoundError('No existing file and no input data')
     else:
-        if data:
-            pass
+        if data is not None:
+            if update:
+                with open(file_path, 'wb') as f:
+                    pickle.dump(data, f)
+            else:
+                pass
         else:
             with open(file_path, 'rb') as f:
                 data = pickle.load(f)
